@@ -1,23 +1,7 @@
 /*
-  Copyright (c) 2007 Bruno Virlet <bruno@virlet.org>
+  SPDX-FileCopyrightText: 2007 Bruno Virlet <bruno@virlet.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 #include "timescaleconfigdialog.h"
 #include "prefs.h"
@@ -66,8 +50,8 @@ TimeScaleConfigDialog::TimeScaleConfigDialog(const PrefsPtr &preferences, QWidge
     : QDialog(parent)
     , d(new Private(this, preferences))
 {
-    setWindowTitle(i18n("Timezone"));
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    setWindowTitle(i18nc("@title:window", "Timezone"));
+    auto *mainLayout = new QVBoxLayout(this);
     setModal(true);
 
     QWidget *mainwidget = new QWidget(this);
@@ -88,7 +72,7 @@ TimeScaleConfigDialog::TimeScaleConfigDialog(const PrefsPtr &preferences, QWidge
     shownTimeZones += d->mPreferences->timeScaleTimezones();
     shownTimeZones.removeDuplicates();
 
-    QList<TimeZoneNamePair> availList, selList;
+    QVector<TimeZoneNamePair> availList, selList;
     const auto zoneIds = QTimeZone::availableTimeZoneIds();
     for (const auto &zoneId : qAsConst(zoneIds)) {
         // do not list timezones already shown
@@ -122,7 +106,7 @@ TimeScaleConfigDialog::TimeScaleConfigDialog(const PrefsPtr &preferences, QWidge
             this, &TimeScaleConfigDialog::slotUpdateButton);
 
     for (const TimeZoneNamePair &item : qAsConst(selList)) {
-        QListWidgetItem *widgetItem = new QListWidgetItem(item.first);
+        auto *widgetItem = new QListWidgetItem(item.first);
         widgetItem->setData(TimeZoneNameRole, item.second);
         listWidget->addItem(widgetItem);
     }
@@ -139,8 +123,8 @@ void TimeScaleConfigDialog::slotUpdateButton()
     removeButton->setEnabled(listWidget->currentItem());
     const bool numberElementMoreThanOneElement = (listWidget->count() > 1);
     upButton->setEnabled(numberElementMoreThanOneElement && (listWidget->currentRow() >= 1));
-    downButton->setEnabled(numberElementMoreThanOneElement &&
-                           (listWidget->currentRow() < listWidget->count() - 1));
+    downButton->setEnabled(numberElementMoreThanOneElement
+                           && (listWidget->currentRow() < listWidget->count() - 1));
 }
 
 void TimeScaleConfigDialog::okClicked()
@@ -156,8 +140,8 @@ void TimeScaleConfigDialog::add()
     if (zoneCombo->currentIndex() >= 0) {
         const int numberItem(listWidget->count());
         for (int i = 0; i < numberItem; ++i) {
-            if (listWidget->item(i)->data(TimeZoneNameRole).toString() ==
-                zoneCombo->itemData(zoneCombo->currentIndex(), TimeZoneNameRole).toString()) {
+            if (listWidget->item(i)->data(TimeZoneNameRole).toString()
+                == zoneCombo->itemData(zoneCombo->currentIndex(), TimeZoneNameRole).toString()) {
                 return;
             }
         }
