@@ -1,23 +1,7 @@
 /*
-  Copyright (c) 2008 Bruno Virlet <bruno.virlet@gmail.com>
+  SPDX-FileCopyrightText: 2008 Bruno Virlet <bruno.virlet@gmail.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "monthitem.h"
@@ -43,9 +27,6 @@ using namespace KCalendarCore;
 
 MonthItem::MonthItem(MonthScene *monthScene)
     : mMonthScene(monthScene)
-    , mSelected(false)
-    , mMoving(false)
-    , mResizing(false)
 {
 }
 
@@ -99,7 +80,7 @@ void MonthItem::updateMonthGraphicsItems()
         }
 
         // A new item needs to be created
-        MonthGraphicsItem *newItem = new MonthGraphicsItem(this);
+        auto *newItem = new MonthGraphicsItem(this);
         mMonthGraphicsItemList << newItem;
         newItem->setStartDate(start);
         newItem->setDaySpan(span);
@@ -213,9 +194,13 @@ int MonthItem::daySpan() const
     if (isMoving() || isResizing()) {
         return mOverrideDaySpan;
     }
-
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     QDateTime start(startDate());
     QDateTime end(endDate());
+#else
+    QDateTime start(startDate().startOfDay());
+    QDateTime end(endDate().startOfDay());
+#endif
 
     if (start.isValid() && end.isValid()) {
         return start.daysTo(end);
@@ -249,12 +234,12 @@ bool MonthItem::greaterThan(const MonthItem *e1, const MonthItem *e2)
         }
     }
 
-    return leftStartDate < rightStartDate;
+    return leftStartDate > rightStartDate;
 }
 
 bool MonthItem::greaterThanFallback(const MonthItem *other) const
 {
-    const HolidayMonthItem *h = qobject_cast<const HolidayMonthItem *>(other);
+    const auto *h = qobject_cast<const HolidayMonthItem *>(other);
 
     // If "other" is a holiday, display it first.
     return !h;
@@ -337,7 +322,7 @@ IncidenceMonthItem::~IncidenceMonthItem()
 
 bool IncidenceMonthItem::greaterThanFallback(const MonthItem *other) const
 {
-    const IncidenceMonthItem *o = qobject_cast<const IncidenceMonthItem *>(other);
+    const auto *o = qobject_cast<const IncidenceMonthItem *>(other);
     if (!o) {
         return MonthItem::greaterThanFallback(other);
     }
@@ -722,7 +707,7 @@ HolidayMonthItem::~HolidayMonthItem()
 
 bool HolidayMonthItem::greaterThanFallback(const MonthItem *other) const
 {
-    const HolidayMonthItem *o = qobject_cast<const HolidayMonthItem *>(other);
+    const auto *o = qobject_cast<const HolidayMonthItem *>(other);
     if (o) {
         return MonthItem::greaterThanFallback(other);
     }
