@@ -1,25 +1,9 @@
 /*
-  Copyright (c) 2008 Bruno Virlet <bruno.virlet@gmail.com>
-  Copyright (C) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.net
-  Author: Bertjan Broeksema, broeksema@kde.org
+  SPDX-FileCopyrightText: 2008 Bruno Virlet <bruno.virlet@gmail.com>
+  SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+  SPDX-FileContributor: Bertjan Broeksema <broeksema@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "monthview.h"
@@ -49,7 +33,7 @@ using namespace EventViews;
 namespace EventViews {
 class MonthViewPrivate : public Akonadi::ETMCalendar::CalendarObserver
 {
-    MonthView *q;
+    MonthView *const q;
 
 public: /// Methods
     explicit MonthViewPrivate(MonthView *qq);
@@ -159,12 +143,12 @@ MonthView::MonthView(NavButtonsVisibility visibility, QWidget *parent)
     : EventView(parent)
     , d(new MonthViewPrivate(this))
 {
-    QHBoxLayout *topLayout = new QHBoxLayout(this);
+    auto *topLayout = new QHBoxLayout(this);
     topLayout->addWidget(d->view);
     topLayout->setContentsMargins(0, 0, 0, 0);
 
     if (visibility == Visible) {
-        QVBoxLayout *rightLayout = new QVBoxLayout();
+        auto *rightLayout = new QVBoxLayout();
         rightLayout->setSpacing(0);
         rightLayout->setContentsMargins(0, 0, 0, 0);
 
@@ -188,7 +172,7 @@ MonthView::MonthView(NavButtonsVisibility visibility, QWidget *parent)
         connect(d->fullView, &QAbstractButton::clicked,
                 this, &MonthView::changeFullView);
 
-        QToolButton *minusMonth = new QToolButton(this);
+        auto *minusMonth = new QToolButton(this);
         minusMonth->setIcon(QIcon::fromTheme(QStringLiteral("arrow-up-double")));
         minusMonth->setAutoRaise(true);
         minusMonth->setToolTip(i18nc("@info:tooltip", "Go back one month"));
@@ -198,7 +182,7 @@ MonthView::MonthView(NavButtonsVisibility visibility, QWidget *parent)
         connect(minusMonth, &QAbstractButton::clicked,
                 this, &MonthView::moveBackMonth);
 
-        QToolButton *minusWeek = new QToolButton(this);
+        auto *minusWeek = new QToolButton(this);
         minusWeek->setIcon(QIcon::fromTheme(QStringLiteral("arrow-up")));
         minusWeek->setAutoRaise(true);
         minusWeek->setToolTip(i18nc("@info:tooltip", "Go back one week"));
@@ -208,7 +192,7 @@ MonthView::MonthView(NavButtonsVisibility visibility, QWidget *parent)
         connect(minusWeek, &QAbstractButton::clicked,
                 this, &MonthView::moveBackWeek);
 
-        QToolButton *plusWeek = new QToolButton(this);
+        auto *plusWeek = new QToolButton(this);
         plusWeek->setIcon(QIcon::fromTheme(QStringLiteral("arrow-down")));
         plusWeek->setAutoRaise(true);
         plusWeek->setToolTip(i18nc("@info:tooltip", "Go forward one week"));
@@ -218,7 +202,7 @@ MonthView::MonthView(NavButtonsVisibility visibility, QWidget *parent)
         connect(plusWeek, &QAbstractButton::clicked,
                 this, &MonthView::moveFwdWeek);
 
-        QToolButton *plusMonth = new QToolButton(this);
+        auto *plusMonth = new QToolButton(this);
         plusMonth->setIcon(QIcon::fromTheme(QStringLiteral("arrow-down-double")));
         plusMonth->setAutoRaise(true);
         plusMonth->setToolTip(i18nc("@info:tooltip", "Go forward one month"));
@@ -283,7 +267,7 @@ KCalendarCore::DateList MonthView::selectedIncidenceDates() const
 {
     KCalendarCore::DateList list;
     if (d->scene->selectedItem()) {
-        IncidenceMonthItem *tmp = qobject_cast<IncidenceMonthItem *>(d->scene->selectedItem());
+        auto *tmp = qobject_cast<IncidenceMonthItem *>(d->scene->selectedItem());
         if (tmp) {
             QDate selectedItemDate = tmp->realStartDate();
             if (selectedItemDate.isValid()) {
@@ -469,7 +453,7 @@ Akonadi::Item::List MonthView::selectedIncidences() const
 {
     Akonadi::Item::List selected;
     if (d->scene->selectedItem()) {
-        IncidenceMonthItem *tmp = qobject_cast<IncidenceMonthItem *>(d->scene->selectedItem());
+        auto *tmp = qobject_cast<IncidenceMonthItem *>(d->scene->selectedItem());
         if (tmp) {
             Akonadi::Item incidenceSelected = tmp->akonadiItem();
             if (incidenceSelected.isValid()) {
@@ -490,7 +474,7 @@ void MonthView::reloadIncidences()
 
     MonthItem *itemToReselect = nullptr;
 
-    if (IncidenceMonthItem *tmp = qobject_cast<IncidenceMonthItem *>(d->scene->selectedItem())) {
+    if (auto *tmp = qobject_cast<IncidenceMonthItem *>(d->scene->selectedItem())) {
         d->selectedItemId = tmp->akonadiItem().id();
         d->selectedItemDate = tmp->realStartDate();
         if (!d->selectedItemDate.isValid()) {
