@@ -1,26 +1,9 @@
 /*
   This file is part of KOrganizer.
 
-  Copyright (c) 2008 Thomas Thrainer <tom_t@gmx.at>
+  SPDX-FileCopyrightText: 2008 Thomas Thrainer <tom_t@gmx.at>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "todoviewsortfilterproxymodel.h"
@@ -30,10 +13,8 @@
 
 #include <KLocalizedString>
 
-TodoViewSortFilterProxyModel::TodoViewSortFilterProxyModel(const EventViews::PrefsPtr &prefs,
-                                                           QObject *parent)
+TodoViewSortFilterProxyModel::TodoViewSortFilterProxyModel(const EventViews::PrefsPtr &prefs, QObject *parent)
     : QSortFilterProxyModel(parent)
-    , mSortOrder(Qt::AscendingOrder)
     , mPreferences(prefs)
 {
 }
@@ -44,8 +25,7 @@ void TodoViewSortFilterProxyModel::sort(int column, Qt::SortOrder order)
     QSortFilterProxyModel::sort(column, order);
 }
 
-bool TodoViewSortFilterProxyModel::filterAcceptsRow(int source_row,
-                                                    const QModelIndex &source_parent) const
+bool TodoViewSortFilterProxyModel::filterAcceptsRow(int source_row, const QModelIndex &source_parent) const
 {
     bool ret = QSortFilterProxyModel::filterAcceptsRow(source_row, source_parent);
 
@@ -184,17 +164,16 @@ void TodoViewSortFilterProxyModel::setPriorityFilter(const QStringList &prioriti
     invalidateFilter();
 }
 
-int TodoViewSortFilterProxyModel::compareStartDates(const QModelIndex &left,
-                                                    const QModelIndex &right) const
+int TodoViewSortFilterProxyModel::compareStartDates(const QModelIndex &left, const QModelIndex &right) const
 {
     Q_ASSERT(left.column() == TodoModel::StartDateColumn);
     Q_ASSERT(right.column() == TodoModel::StartDateColumn);
 
     // The due date column is a QString so fetch the akonadi item
     // We can't compare QStrings because it won't work if the format is MM/DD/YYYY
-    const KCalCore::Todo::Ptr leftTodo
+    const KCalendarCore::Todo::Ptr leftTodo
         = CalendarSupport::todo(left.data(TodoModel::TodoRole).value<Akonadi::Item>());
-    const KCalCore::Todo::Ptr rightTodo
+    const KCalendarCore::Todo::Ptr rightTodo
         = CalendarSupport::todo(right.data(TodoModel::TodoRole).value<Akonadi::Item>());
 
     if (!leftTodo || !rightTodo) {
@@ -231,17 +210,16 @@ void TodoViewSortFilterProxyModel::setCategoryFilter(const QStringList &categori
  *  0 - equal
  *  1 - bigger than
  */
-int TodoViewSortFilterProxyModel::compareDueDates(const QModelIndex &left,
-                                                  const QModelIndex &right) const
+int TodoViewSortFilterProxyModel::compareDueDates(const QModelIndex &left, const QModelIndex &right) const
 {
     Q_ASSERT(left.column() == TodoModel::DueDateColumn);
     Q_ASSERT(right.column() == TodoModel::DueDateColumn);
 
     // The due date column is a QString so fetch the akonadi item
     // We can't compare QStrings because it won't work if the format is MM/DD/YYYY
-    const KCalCore::Todo::Ptr leftTodo
+    const KCalendarCore::Todo::Ptr leftTodo
         = CalendarSupport::todo(left.data(TodoModel::TodoRole).value<Akonadi::Item>());
-    const KCalCore::Todo::Ptr rightTodo
+    const KCalendarCore::Todo::Ptr rightTodo
         = CalendarSupport::todo(right.data(TodoModel::TodoRole).value<Akonadi::Item>());
 
     if (!leftTodo || !rightTodo) {
@@ -272,8 +250,7 @@ int TodoViewSortFilterProxyModel::compareDueDates(const QModelIndex &left,
  *  0 - equal
  *  1 - bigger than
  */
-int TodoViewSortFilterProxyModel::compareCompletion(const QModelIndex &left,
-                                                    const QModelIndex &right) const
+int TodoViewSortFilterProxyModel::compareCompletion(const QModelIndex &left, const QModelIndex &right) const
 {
     Q_ASSERT(left.column() == TodoModel::PercentColumn);
     Q_ASSERT(right.column() == TodoModel::PercentColumn);
@@ -283,9 +260,9 @@ int TodoViewSortFilterProxyModel::compareCompletion(const QModelIndex &left,
 
     if (leftValue == 100 && rightValue == 100) {
         // Untie with the completion date
-        const KCalCore::Todo::Ptr leftTodo
+        const KCalendarCore::Todo::Ptr leftTodo
             = CalendarSupport::todo(left.data(TodoModel::TodoRole).value<Akonadi::Item>());
-        const KCalCore::Todo::Ptr rightTodo
+        const KCalendarCore::Todo::Ptr rightTodo
             = CalendarSupport::todo(right.data(TodoModel::TodoRole).value<Akonadi::Item>());
 
         if (!leftTodo || !rightTodo) {
@@ -302,8 +279,7 @@ int TodoViewSortFilterProxyModel::compareCompletion(const QModelIndex &left,
  *  0 - equal
  *  1 - bigger than
  */
-int TodoViewSortFilterProxyModel::comparePriorities(const QModelIndex &left,
-                                                    const QModelIndex &right) const
+int TodoViewSortFilterProxyModel::comparePriorities(const QModelIndex &left, const QModelIndex &right) const
 {
     Q_ASSERT(left.column() == TodoModel::PriorityColumn);
     Q_ASSERT(right.column() == TodoModel::PriorityColumn);
